.. ocpa documentation master file, created by
   sphinx-quickstart on Wed Aug 10 11:18:01 2022.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to ocpa's documentation!
================================

.. image:: _static/traditional_oc.PNG
   :width: 500px
   :align: center

Object-Centric Process Mining: Moving from homogeneous event sequences to heterogeneous event graphs.

Installation
------------

Install from Github

.. code-block:: text

    git clone https://github.com/ocpm/ocpa.git
    cd ocpa
    pip install .

Install from Pip

.. code-block:: text

    pip install ocpa



.. toctree::
   :maxdepth: 2
   :caption: Contents:

   Event Log Management <eventlogmanagement>
   Process Discovery <discovery>
   Conformance Checking <conformance_checking>
   Process Enhancement <enhancement>
   Predictive Monitoring <monitoring>
   Documentation <modules>



Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
